==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/AssigningRadialStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningRadialStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningRadialStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningRadialStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ac("AssigningRadialStyleEventArgsBase", AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningRadialStyleEventArgsBaseDescriptionMetadata, 'AssigningRadialStyleEventArgsBaseDescriptionMetadata');
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsBaseDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/AssigningRadialStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let AssigningRadialStyleEventArgsBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class AssigningRadialStyleEventArgsBaseDescriptionMetadata extends Base {
        static b(a) {
            if (AssigningRadialStyleEventArgsBaseDescriptionMetadata.a == null) {
                AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                AssigningRadialStyleEventArgsBaseDescriptionMetadata.c(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
            }
            if (a.k(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
        }
        static c(a) {
            AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            AssigningRadialStyleEventArgsBaseDescriptionMetadata.b(a);
            a.ad("AssigningRadialStyleEventArgsBase", AssigningRadialStyleEventArgsBaseDescriptionMetadata.a);
        }
    }
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningRadialStyleEventArgsBaseDescriptionMetadata, 'AssigningRadialStyleEventArgsBaseDescriptionMetadata');
    AssigningRadialStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningRadialStyleEventArgsBaseDescriptionMetadata;
})();
